@@ -24,20 +24,22 @@
 #define CHECKSUMTOOLFACTORY_H
 
 // lib
-#include <kasten/okteta/oktetakastencontrollers_export.h>
+#include "oktetakastencontrollers_export.h"
 // Kasten core
-#include <kasten/abstracttoolfactory.h>
+#include <abstracttoolfactory.h>
 
-namespace Kasten {
+
+namespace Kasten2
+{
 
 class OKTETAKASTENCONTROLLERS_EXPORT ChecksumToolFactory : public AbstractToolFactory
 {
-public:
+  public:
     ChecksumToolFactory();
-    ~ChecksumToolFactory() override;
+    virtual ~ChecksumToolFactory();
 
-public: // AbstractToolFactory API
-    AbstractTool* create() override;
+  public: // AbstractToolFactory API
+    virtual AbstractTool* create();
 };
 
 }
